abacusai.point_in_time_feature — AbacusAI documentation

# `abacusai.point_in_time_feature`

## Module Contents

### Classes

`PointInTimeFeature` | A point in time feature description

class abacusai.point_in_time_feature.PointInTimeFeature(client, historyTableName=None, aggregationKeys=None, timestampKey=None, historicalTimestampKey=None, lookbackWindowSeconds=None, lookbackWindowLagSeconds=None, lookbackCount=None, lookbackUntilPosition=None, expression=None, groupName=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A point in time feature description

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - historyTableName (str) – The table name of the history table. If not specified, we use the current table to do a self join.

    - aggregationKeys (list of string) – List of keys to use for join the historical table and performing the window aggregation.

    - timestampKey (str) – Name of feature which contains the timestamp value for the point in time feature

    - historicalTimestampKey (str) – Name of feature which contains the historical timestamp.

    - lookbackWindowSeconds (float) – If window is specified in terms of time, number of seconds in the past from the current time for start of the window.

    - lookbackWindowLagSeconds (float) – Optional lag to offset the closest point for the window. If it is positive, we delay the start of window. If it is negative, we are looking at the “future” rows in the history table.

    - lookbackCount (int) – If window is specified in terms of count, the start position of the window (0 is the current row)

    - lookbackUntilPosition (int) – Optional lag to offset the closest point for the window. If it is positive, we delay the start of window by that many rows. If it is negative, we are looking at those many “future” rows in the history table.

    - expression (str) – SQL Aggregate expression which can convert a sequence of rows into a scalar value.

    - groupName (str) – The group name this point in time feature belongs to

  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict